@@ -335,5 +335,5 @@ def upload_image(**kwargs):
                                         image=customer_img)
     environ.update({'_IMAGE_REPO': image_repo})
     push_image(tags)
-    notify_orchest(image_sha, customer_img, is_latest=is_latest)
+    notify_orchest(image_sha, is_latest=is_latest)
     sys.exit(0)
