@@ -1,7 +1,7 @@
 # coding: utf-8
 
 from vxci.get_addons import get_module_list, get_modules2test
-from vxbase import types
+from vxbase import types, net
 import distutils.spawn
 from docker import errors, from_env
 import json
@@ -14,6 +14,7 @@ import subprocess
 import sys
 import time
 from urllib3.exceptions import ReadTimeoutError
+from unicodedata import normalize
 from shutil import copy, rmtree
 
 
@@ -172,6 +173,27 @@ def is_dev_repo(config):
     return config.get('ci_commit_ref_name') != config['version'] or config.get('ci_project_namespace').endswith('-dev')
 
 
+def slugify(s):
+    slug = normalize('NFKD', s)
+    slug = slug.encode('ascii', 'ignore').lower()
+    slug = re.sub(r'[^a-z0-9]+', '-', slug).strip('-')
+    return re.sub(r'[-]+', '-', slug)
+
+
+def map_github_action(config):
+    config['ci_commit_ref_name'] = config.get('github_ref_name')
+    config['ci_job_id'] = config.get('github_run_id')
+    config['ci_pipeline_id'] = config.get('github_run_number')
+    config['ci_project_name'] = config.get('customer')
+    repos = config.get('github_repository', '').split('/')
+    if len(repos) > 1:
+        config['ci_project_name'] = repos[1]
+    config['ci_commit_ref_slug'] = slugify(config.get('github_ref_name'))
+    config['ci_repository_url'] = net.urljoin(config.get('github_server_url'), config.get('github_repository'))
+    config['ci_commit_sha'] = config.get('github_sha')
+    config['ci_project_namespace'] = config.get('github_repository_owner')
+
+
 def get_config(**kwargs):
     rand_str = 'hd103sl'
     res = {}
@@ -181,6 +203,8 @@ def get_config(**kwargs):
     for key in kwargs:
         res.update({key.lower(): get_value(key, **kwargs)})
 
+    if res.get('github_action', False):
+        map_github_action(res)
     res.update({'private_deploy_key': res.get('private_deploy_key', False)})
     img_name = generate_image_name('{0}_{1}'.format(
         res['ci_commit_ref_name'], res['ci_job_id']))
